/*
  Xinvest is copyright 1996 by Mark Buser.

  Permission is hereby granted to copy
  and freely distribute copies of this
  program for non-commercial purposes
  without fee, provided that this notice
  appears in all copies.
  
  All redistributions must be in their
  entirety as originally distributed.
  Feel free to modify Xinvest, but
  modified versions may not be distributed
  without prior consent of the author.
  
  This software is provided 'as-is'
  without any express or implied warranty.
  In no event will the author be held
  liable for any damages resulting from
  the use of this software.

  $Revision: 2.1 $ $Date: 1998/04/26 18:58:41 $
*/

void sessDie (Widget, XtPointer, XtPointer);
void sessSave (Widget, XtPointer, XtPointer);
void sessResume (Widget, XtPointer, XtPointer);

int restoreState (char *);
int saveState (char *);
char *sessSaveFile (Boolean);
